@@ -1,10 +1,10 @@
 from array import array
 from pathlib import Path
 import pathlib
-
+from ase import Atoms, Atom
+from ase.data import chemical_symbols
 from ase.units import Bohr
 import numpy as np
-from openbabel import openbabel as ob
 
 
 class LTMatrix(list):
@@ -143,7 +143,7 @@ class Geometry:
         self.energy = None
         """Energy associated with geometry based on the DFT or higher level calculations used to generate the .fchk file input"""
         self.atoms = list()
-        """List of <SITH_Utilities.Atom> objects associated with geometry."""
+        """<ase.Atoms> object associated with geometry."""
         self.nAtoms = nAtoms
         """Number of atoms"""
         self.dims = array('i')
@@ -160,24 +160,12 @@ class Geometry:
         """Hessian matrix associated with the geometry. If 'None', then the associated fchk file did not contain any Hessian,
         in the case of Gaussian the Hessian is generated when a freq analysis is performed."""
 
-    def buildCartesian(self, lines: list):
-        """Takes in a list of str containing the lines of a .xyz file, populates self.atoms
-
-        -----
-        Data is assumed to be Cartesian and in Angstroms as is standard for .xyz files"""
-        first = lines[0]
-        if len(first.split()) == 1:
-            nAtoms = int(first)
-            if nAtoms != self.nAtoms:
-                raise Exception("Mismatch in number of atoms.")
-        for line in lines:
-            sLine = line.split()
-            if len(sLine) == 4:
-                coords = [float(x) for x in sLine[1:4]]
-                a = Atom(sLine[0], coords)
-                self.atoms.append(a)
-            else:
-                pass
+    def buildAtoms(self, raw_coords:list, atomic_num:list):
+        assert len(raw_coords) == len(atomic_num) * 3, str(len(raw_coords))+" cartesian coordinates given, incorrect for "+str(len(atomic_num))+" atoms."
+        atomic_coord = [Bohr * float(raw_coord) for raw_coord in raw_coords]
+        atomic_coord = np.reshape(atomic_coord, (self.nAtoms, 3))
+        molecule = ''.join([chemical_symbols[int(i)] for i in atomic_num])
+        self.atoms = Atoms(molecule, atomic_coord)
 
     def buildRIC(self, dims: list, dimILines: list, coordLines: list):
         """
@@ -260,10 +248,9 @@ class Geometry:
         assert len(self.ric) == self.dims[0], "Mismatch between the number of degrees of freedom expected ("+str(
             dims[0])+") and number of coordinates given ("+str(len(self.ric))+")."
 
-        # Angles are moved from (-pi, pi) --> (0, 2pi) because abs(angles) are often around pi (phi, psi angles especially)
-        # so when calculating deltaQ this is more convenient
+        # Angles are moved (-pi, pi)
         for i in range(self.dims[1], self.dims[0]):
-            self.ric[i] = self.ric[i] + np.pi
+            self.ric[i] = self.ric[i]
 
     def _killDOFs(self, dofis: list[int]):
         """Takes in list of indices of degrees of freedom to remove, Removes DOFs from ric, dimIndices, and hessian, updates dims"""
@@ -296,17 +283,6 @@ class Geometry:
         return b
 
 
-class Atom:
-    """Holds Cartesian coordinate data as well as element data"""
-
-    def __init__(self, element: str, coords: list) -> None:
-        self.element = element
-        self.coords = coords
-
-    def __eq__(self, __o: object) -> bool:
-        return self.element == __o.element and all([self.coords[i] == __o.coords[i] for i in range(3)])
-
-
 class UnitConverter:
     """
     Class to convert units utilizing Atomic Simulation Environment (ase) constants
@@ -364,6 +340,7 @@ class Extractor:
 
         try:
             i = 0
+            atomicNums = list()
             while i < len(self.__lines):
                 line = self.__lines[i]
 
@@ -374,6 +351,15 @@ class Extractor:
                     numAtoms = int(splitLine[len(splitLine)-1])
                     self.geometry = Geometry(self._name, self._path, numAtoms)
 
+                if self.__atomicNumsHeader in line:
+                    i += 1
+                    stop = int(line.split()[-1])
+                    count = 0
+                    while count < stop:
+                        atomicNums.extend(self.__lines[i].split())
+                        count += len(self.__lines[i].split())
+                        i += 1
+
                 elif self.__energyHeader in line:
                     splitLine = line.split()
                     self.geometry.energy = float(splitLine[len(splitLine)-1])
@@ -405,6 +391,19 @@ class Extractor:
                     xrRaw = self.__lines[xrStart:i]
                     self.geometry.buildRIC(rDims, xrDims, xrRaw)
 
+                if self.__cartesianCoordsHeader in line:
+                    i = i+1
+                    cStart = i
+                    stop = int(line.split()[-1])
+                    count = 0
+                    cRaw = list()
+                    while count < stop:
+                        cRaw.extend(self.__lines[i].split())
+                        count += len(self.__lines[i].split())
+                        i += 1
+                    assert len(atomicNums) == numAtoms, "Mismatch between length of atomic numbers and number of atoms specified."
+                    self.geometry.buildAtoms(cRaw, atomicNums)
+
                 elif self.__hessianHeader in line:
                     i = i+1
                     stop = int(line.split()[-1])
@@ -415,20 +414,12 @@ class Extractor:
                         self.hRaw.extend([float(i) for i in rowsplit])
                         i = i+1
 
+                
+                    
                 i = i + 1
             print("Building full Hessian matrix.")
             self.buildHessian()
 
-            print("Translating .fchk file to new .xyz file with OpenBabel...")
-
-            obConversion = ob.OBConversion()
-            obConversion.SetInAndOutFormats("fchk", "xyz")
-            mol = ob.OBMol()
-            assert self._path.exists(), "Path to fchk file does not exist"
-            assert obConversion.ReadFile(mol, self._path.as_posix(
-            )), "Reading fchk file ("+self._path.as_posix()+") with openbabel failed."
-            xyzString = obConversion.WriteString(mol)
-            self.geometry.buildCartesian(xyzString.split('\n'))
 
             print("Cartesian data extracted successfully.")
             return True
@@ -449,3 +440,151 @@ class Extractor:
             return self.geometry
         else:
             raise Exception("There is no geometry.")
+
+
+class void:
+    pass
+
+
+class SummaryReader:
+    def __init__(self, file):
+        """
+        Extract the data in a summary file
+        """
+        with open(file) as data:
+            self.info = data.readlines()
+
+        self._reference = void()
+        self._deformed = list()
+        self.read_all()
+
+    def read_section(self, header, tail, iplus=0, jminus=0):
+        """
+        Take any block of a set of lines separated by header
+        and tail as references
+
+        lines: list
+            set of lines to extract the blocks
+        header:
+            line that marks the start of the block. It is included
+            in the block.
+        tail:
+            line that marks the end of the block. It is not included
+            in the block.
+        iplus: int
+            number of lines to ignore after header
+        jminus:
+            number of lines to ignore before the tail
+        """
+        i = self.info.index(header)
+        j = self.info.index(tail)
+        data = self.info[i+iplus:j-jminus]
+        return data
+
+    def read_dofs(self):
+        """
+        read the degrees of freedom in the summary file
+
+        return the dofs in a list.
+        """
+
+        lines = self.read_section('Redundant Internal Coordinate' +
+                                  ' Definitions\n',
+                                  'Changes in internal coordinates' +
+                                  ' (Delta q)\n',
+                                  iplus=2)
+        return [np.fromstring(line.replace('(',
+                                           '').replace(',',
+                                                       '').replace(')',
+                                                                   ''),
+                sep=' ', dtype=int)[1:].tolist()
+                for line in lines]
+
+    def read_changes(self):
+        """
+        read the changes in the degrees of freedom in the summary file
+
+        return a list of lists where the i-th list is the changes in the
+        i-th deformed config.
+        """
+        lines = self.read_section('Changes in internal coordinates' +
+                                  ' (Delta q)\n',
+                                  '**  Energy Analysis  **\n',
+                                  iplus=3, jminus=2)
+        return np.array([np.fromstring(line, sep=' ')[1:] for line in lines]).T
+
+    def read_accuracy(self):
+        """
+        read the accuracy in the total difference of energy.
+
+        return a list lists where each element corresponds with the
+        energy-analysis of each deformed config saved as
+        [energy diff predicted with harmonic approx, percentaje_error, Error]
+         """
+        lines = self.read_section('Overall Structural Energies\n',
+                                  'Energy per DOF (RIC)\n',
+                                  iplus=2)
+
+        return np.array([np.array(line.split()[1:],
+                                  dtype=float)
+                         for line in lines]).T
+
+    def read_energies(self, ndofs):
+        """
+        read the energies in each degree of freedom
+
+        return a list lists where each element corresponds to the
+        distribution of energies of each deformed config
+        """
+        lines = self.read_section('Energy per DOF (RIC)\n',
+                                  'Energy per DOF (RIC)\n',
+                                  iplus=2, jminus=-ndofs-2)
+
+        return np.array([np.array(line.split(),
+                                  dtype=float)
+                         for line in lines])
+
+    def read_structures(self):
+        """
+        Creates the ase.Atoms objects of each structure.
+        """
+        init = self.info.index("XYZ FILES APPENDED\n") + 1
+        n_configs = len(self.deltaQ) + 1  # deformed plus reference
+        length = int(len(self.info[init:])/n_configs)
+        n_atoms = int(self.info[init+1])
+
+        configs = [self.info[init+i*(length):init+(i+1)*length]
+                   for i in range(n_configs)]
+        configs = [[atom.split() for atom in config] for config in configs]
+        molecule = ''.join([atom[0] for atom in configs[0][-n_atoms:]])
+        positions = np.array([[np.array(atom[1:], dtype=float)
+                              for atom in config[-n_atoms:]]
+                              for config in configs])
+
+        atoms = [Atoms(molecule, config) for config in positions]
+
+        return atoms[0], atoms[1:]
+
+    def read_all(self):
+        """
+        Read all summary file and save the info in instances
+        """
+        self.dimIndices = self.read_dofs()
+        dims = [len(self.dimIndices), 0, 0, 0]
+        for dof in self.dimIndices:
+            dims[len(dof)-1] += 1
+        self._reference.dims = dims
+        self.deltaQ = self.read_changes()
+        self.accuracy = self.read_accuracy()
+        assert len(self.dimIndices) == len(self.deltaQ[0]), \
+            f'{len(self.dimIndices)} DOF' +\
+            f'but {len(self.deltaQ[0])} changes are reported'
+
+        self.energies = self.read_energies(len(self.deltaQ[0]))
+        self._reference.atoms, deformed = self.read_structures()
+        [self._deformed.append(void()) for _ in range(len(deformed))]
+
+        for i in range(len(deformed)):
+            self._deformed[i].atoms = deformed[i]
+
+        self._reference.dimIndices = self.dimIndices
